@@ -40,7 +40,11 @@ survspat <- function(   formula,
     }                     
 
     # okay, start the MCMC!
-    start <- Sys.time()
+
+    # start timing, maybe
+    if(!control$timeonlyMCMC){
+        start <- Sys.time()
+    }
 
     coords <- coordinates(data)
 
@@ -70,7 +74,7 @@ survspat <- function(   formula,
         dyidx <- pmin(abs(yidx-yidx[1]),Next-abs(yidx-yidx[1]))
         u <- sqrt(((x[2]-x[1])*dxidx)^2+((y[2]-y[1])*dyidx)^2)
         
-        spix <- grid2spix(xgrid=mcens,ygrid=mcens)
+        spix <- grid2spix(xgrid=mcens,ygrid=ncens,proj4string=CRS(proj4string(data)))
         
         control$fftgrid <- gridobj
         control$idx <- over(data,geometry(spix))
@@ -237,6 +241,11 @@ survspat <- function(   formula,
     
     gammamean <- 0
     count <- 1
+
+    # start timing, maybe
+    if(control$timeonlyMCMC){
+        start <- Sys.time()
+    }
     
     
     while(nextStep(mcmcloop)){
@@ -365,7 +374,7 @@ survspat <- function(   formula,
     
     ####    
     
-    colnames(betasamp) <- attr(Terms,"term.labels")
+    colnames(betasamp) <- colnames(model.matrix(formula,data))[-1] #attr(Terms,"term.labels")
     retlist$betasamp <- betasamp
     retlist$omegasamp <- omegasamp
     retlist$etasamp <- etasamp
@@ -385,6 +394,9 @@ survspat <- function(   formula,
         retlist$N <- Next/control$ext
         retlist$xvals <- mcens[1:retlist$M]
         retlist$yvals <- ncens[1:retlist$N]
+        lookup <- as.vector(matrix(1:(Mext*Next),Mext,Next)[1:retlist$M,1:retlist$N])
+        ref <- as.vector(matrix(1:(retlist$M*retlist$N),retlist$M,retlist$N))
+        retlist$cellidx <- sapply(control$idx,function(i){ref[lookup==i]})
     }
     
     retlist$tarrec <- tarrec
